Release Notes — Pootle 2.5.0 documentation

Pootle 2.5.0

- Site
  - User’s guide
  - Features
  - Administering a server
  - Developers
  - Changelog
  - Release Notes
  - External documentation
  - License
- Page
  - Release Notes
- « Changelog
- Welcome to the new Pootle 2.5.0 »

# Release Notes

The following are release notes used on PyPI, Sourceforge and mailing lists for Pootle releases.

- Welcome to the new Pootle 2.5.0
- Welcome to the new Pootle 2.5.0-rc1